@@ -4,16 +4,11 @@
 
 #include "config.h"
 
-#ifdef ENABLE_CLIENT
-int   ipc_init    (void);
+int   ipc_init    (char *path);
 void  ipc_exit    (void);
 
 int   ipc_send    (int sd, char *buf, size_t len);
 void *ipc_receive (int sd, char *buf, size_t len);
-#else
-#define ipc_init()
-#define ipc_exit()
-#endif
 
 #endif /* SMCROUTE_IPC_H_ */
 
